@@ -28,7 +28,7 @@ def generate_edgelist(df):
     Note
     ----
     - In order to generate a **networkx** object it's only required to give the list to the Graph() constructor
-    >>> edgelist = generate_edgelist(DataFrame)
+    >>> edgelist = xn2v.generate_edgelist(DataFrame)
     >>> G = nx.Graph()
     >>> G.add_weighted_edges_from(edgelist)
     - The data types of the 'node1' and 'node2' columns must be strings, otherwise they will be converted as strings.
@@ -37,7 +37,7 @@ def generate_edgelist(df):
     --------
     >>> import pandas as pd
     >>> df = pd.DataFrame(np.array([[1, 2, 3.7], [1, 3, 0.33], [2, 7, 12]]), columns=['node1', 'node2', 'weight'])
-    >>> edgelist = generate_edgelist(df)
+    >>> edgelist = xn2v.generate_edgelist(df)
         [('1.0', '2.0', 3.7), ('1.0', '3.0', 0.33), ('2.0', '7.0', 12.0)]
     """
     # forcing type values
@@ -69,14 +69,14 @@ def edgelist_from_csv(path, **kwargs):
     Note
     ----
     - In order to generate a **networkx** object it's only required to give the list to the Graph() constructor
-    >>> edgelist = get_edgelist('some_edgelist.csv')
+    >>> edgelist = xn2v.edgelist_from_csv('some_edgelist.csv')
     >>> G = nx.Graph()
     >>> G.add_weighted_edges_from(edgelist)
     - The data types of the 'node1' and 'node2' columns must be strings, otherwise they will be converted as strings.
     
     Examples
     --------
-    >>> edgelist = edgelist_from_csv('somefile.csv')
+    >>> edgelist = xn2v.edgelist_from_csv('somefile.csv')
         [('a','1',3.4),('a','2',0.6),('a','b',10)]
     """
     df_csv = pd.read_csv(path, dtype = {'node1': str, 'node2': str, 'weight': np.float64}, **kwargs)
@@ -111,7 +111,7 @@ def complete_edgelist(Z, info=False, **kwargs):
         >>> x1 = np.random.normal(7, 1, 3)
         >>> y1 = np.random.normal(9, 1, 3)
         >>> points = np.column_stack((x1, y1))
-        >>> df = complete_edgelist(points)
+        >>> df = xn2v.complete_edgelist(points)
               node1 node2    weight
             0     0     0  0.000000
             1     0     1  1.358972
@@ -169,7 +169,7 @@ def stellar_edgelist(Z, info=False, **kwargs):
     >>> x1 = np.random.normal(7, 1, 6)
     >>> y1 = np.random.normal(9, 1, 6)
     >>> points_1 = np.column_stack((x1, y1))
-    >>> df = stellar_edgelist(points_1)
+    >>> df = xn2v.stellar_edgelist(points_1)
           node1 node2     weight
         0     0     1  12.571278
         1     0     2  11.765633
@@ -182,7 +182,7 @@ def stellar_edgelist(Z, info=False, **kwargs):
     >>> y2 = np.random.normal(101, 1, 3)
     >>> points_2 = np.column_stack((x2, y2))
     >>> tot = np.concatenate((points_1,points_2),axis=0)
-    >>> df = stellar_edgelist(tot)
+    >>> df = xn2v.stellar_edgelist(tot)
           node1 node2     weight
         0     0     1  12.571278
         1     0     2  11.765633
@@ -234,7 +234,7 @@ def best_line_projection(Z):
     >>> x1 = np.random.normal(7, 1, 6)
     >>> y1 = np.random.normal(9, 1, 6)
     >>> points = np.column_stack((x1, y1))
-    >>> best_line_projection(points)
+    >>> xn2v.best_line_projection(points)
         [[-0.15079291  1.12774076]
          [ 2.65759595  4.44293266]
          [ 3.49319696  5.42932658]]
@@ -248,6 +248,72 @@ def best_line_projection(Z):
     projections = np.reshape(projections, (NPoints, dimension))
     return projections
 
+def recover_points(Z, G, nodes):
+    """
+        Description
+        -----------
+        Recovers the spatial points from the analyzed network. It uses the fact that the order of the nodes that build
+        the network is the same as the dataset one, therefore there is a one-to-one correspondence between nodes and
+        points.
+
+        Parameters
+        ----------
+        Z : numpy ndarray
+            Numpy array containing as columns the i-th coordinate of the k-th point. The rows are the points, the columns
+            are the coordinates.
+        G : networkx.Graph()
+            Gives the network that has been analyzed.
+        nodes : list
+            List of the *most similar nodes* obtained after the analysis on the network G. The type is forced to be a
+            string.
+
+        Returns
+        -------
+        output : numpy ndarray
+            The output of the function is a numpy ndarray containing the required points from the dataset.
+
+        Examples
+        --------
+        >>> x1 = np.random.normal(16, 2, 30)
+        >>> y1 = np.random.normal(9, 2, 30)
+        >>> x2 = np.random.normal(100, 2, 30)
+        >>> y2 = np.random.normal(100, 2, 30)
+        >>> family1 = np.column_stack((x1, y1)) # REQUIRED ARRAY FORMAT
+        >>> family2 = np.column_stack((x2, y2)) # REQUIRED ARRAY FORMAT
+        >>> dataset = np.concatenate((family1,family2),axis=0) # Generic dataset
+        >>> df = xn2v.complete_edgelist(dataset) # Pandas edge list generation
+        >>> df = xn2v.generate_edgelist(df)
+        >>> G = nx.Graph()
+        >>> G.add_weighted_edges_from(df)
+        >>> nodes, similarity = xn2v.similar_nodes(G,node='1',picked=10,walk_length=20,dim=100,context=5,Weight=True)
+        >>> cluseter = xn2v.recover_points(dataset,G,nodes)
+        [[17.98575878  8.99318017]
+         [18.03438744  9.46128979]
+         [15.83803679 10.39565391]
+         [15.95210332 10.4135796 ]
+         [19.44550252 12.7551321 ]
+         [18.62321691 10.7604561 ]
+         [16.30640697 12.15702448]
+         [18.73718742 13.99351914]
+         [18.7817838   7.92318885]
+         [16.15456589 10.72636297]]       
+        """
+    # check dimensionality
+    if Z[:,0].size != np.array(G.nodes).size:
+        print('dataset: ',Z[:,0].size)
+        print('network: ', np.array(G.nodes).size)
+        raise Exception('Error: the dataset dimension is different from the one of the network.')
+    # force string type
+    nodes = [str(s) for s in nodes]
+    picked_nodes = []
+    pos = 0
+    for n in G:
+        if n in nodes:
+            picked_nodes.append(Z[pos])
+        pos += 1
+    return np.array(picked_nodes)
+
+
 def similar_nodes(G, node=1, picked=10, train_time = 30, Weight=False, save_model = False, 
                   model_name = 'model.wordvectors' , **kwargs):
     """
